@@ -13,7 +13,7 @@ use MIME::Base64;
 use Yote::Account;
 use Yote::YoteRoot;
 
-use base 'Yote::Obj';
+use base 'Yote::RootObj';
 
 use vars qw($VERSION);
 $VERSION = '0.087';
@@ -84,6 +84,8 @@ sub __get_account {
         $accts->{$login->{ID}} = $acct;
 	$self->_init_account( $acct );
     }
+    die "Access Error" if $acct->get__is_disabled();
+    
     return $acct;
 
 } #__get_account
